Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MountKeysController ¶
func MountKeysController(service *goa.Service, ctrl KeysController)
MountKeysController "mounts" a Keys resource controller on the given service.
Types ¶
type GetElementKeysContext ¶
type GetElementKeysContext struct {
context.Context
*goa.ResponseData
*goa.RequestData
Element string
Key string
}
GetElementKeysContext provides the keys getElement action context.
func NewGetElementKeysContext ¶
func NewGetElementKeysContext(ctx context.Context, service *goa.Service) (*GetElementKeysContext, error)
NewGetElementKeysContext parses the incoming request URL and body, performs validations and creates the context used by the keys controller getElement action.
func (*GetElementKeysContext) BadRequest ¶
func (ctx *GetElementKeysContext) BadRequest(r error) error
BadRequest sends a HTTP response with status code 400.
func (*GetElementKeysContext) NotFound ¶
func (ctx *GetElementKeysContext) NotFound(r error) error
NotFound sends a HTTP response with status code 404.
func (*GetElementKeysContext) OK ¶
func (ctx *GetElementKeysContext) OK(r interface{}) error
OK sends a HTTP response with status code 200.
type GetKeysContext ¶
type GetKeysContext struct {
context.Context
*goa.ResponseData
*goa.RequestData
Key string
}
GetKeysContext provides the keys get action context.
func NewGetKeysContext ¶
NewGetKeysContext parses the incoming request URL and body, performs validations and creates the context used by the keys controller get action.
func (*GetKeysContext) BadRequest ¶
func (ctx *GetKeysContext) BadRequest(r error) error
BadRequest sends a HTTP response with status code 400.
func (*GetKeysContext) NotFound ¶
func (ctx *GetKeysContext) NotFound(r error) error
NotFound sends a HTTP response with status code 404.
func (*GetKeysContext) OK ¶
func (ctx *GetKeysContext) OK(r interface{}) error
OK sends a HTTP response with status code 200.
type KeysController ¶
type KeysController interface {
goa.Muxer
Get(*GetKeysContext) error
GetElement(*GetElementKeysContext) error
List(*ListKeysContext) error
Remove(*RemoveKeysContext) error
Set(*SetKeysContext) error
Update(*UpdateKeysContext) error
}
KeysController is the controller interface for the Keys actions.
type ListKeysContext ¶
type ListKeysContext struct {
context.Context
*goa.ResponseData
*goa.RequestData
}
ListKeysContext provides the keys list action context.
func NewListKeysContext ¶
NewListKeysContext parses the incoming request URL and body, performs validations and creates the context used by the keys controller list action.
func (*ListKeysContext) OK ¶
func (ctx *ListKeysContext) OK(r []string) error
OK sends a HTTP response with status code 200.
type RemoveKeysContext ¶
type RemoveKeysContext struct {
context.Context
*goa.ResponseData
*goa.RequestData
Key string
}
RemoveKeysContext provides the keys remove action context.
func NewRemoveKeysContext ¶
NewRemoveKeysContext parses the incoming request URL and body, performs validations and creates the context used by the keys controller remove action.
func (*RemoveKeysContext) BadRequest ¶
func (ctx *RemoveKeysContext) BadRequest(r error) error
BadRequest sends a HTTP response with status code 400.
func (*RemoveKeysContext) NotFound ¶
func (ctx *RemoveKeysContext) NotFound(r error) error
NotFound sends a HTTP response with status code 404.
func (*RemoveKeysContext) OK ¶
func (ctx *RemoveKeysContext) OK(resp []byte) error
OK sends a HTTP response with status code 200.
type SetKeysContext ¶
type SetKeysContext struct {
context.Context
*goa.ResponseData
*goa.RequestData
Key string
TTL int
Payload SetKeysPayload
}
SetKeysContext provides the keys set action context.
func NewSetKeysContext ¶
NewSetKeysContext parses the incoming request URL and body, performs validations and creates the context used by the keys controller set action.
func (*SetKeysContext) BadRequest ¶
func (ctx *SetKeysContext) BadRequest(r error) error
BadRequest sends a HTTP response with status code 400.
func (*SetKeysContext) OK ¶
func (ctx *SetKeysContext) OK(resp []byte) error
OK sends a HTTP response with status code 200.
type SetKeysPayload ¶
type SetKeysPayload interface{}
SetKeysPayload is the keys set action payload.
type UpdateKeysContext ¶
type UpdateKeysContext struct {
context.Context
*goa.ResponseData
*goa.RequestData
Key string
Payload UpdateKeysPayload
}
UpdateKeysContext provides the keys update action context.
func NewUpdateKeysContext ¶
NewUpdateKeysContext parses the incoming request URL and body, performs validations and creates the context used by the keys controller update action.
func (*UpdateKeysContext) BadRequest ¶
func (ctx *UpdateKeysContext) BadRequest(r error) error
BadRequest sends a HTTP response with status code 400.
func (*UpdateKeysContext) NotFound ¶
func (ctx *UpdateKeysContext) NotFound(r error) error
NotFound sends a HTTP response with status code 404.
func (*UpdateKeysContext) OK ¶
func (ctx *UpdateKeysContext) OK(resp []byte) error
OK sends a HTTP response with status code 200.
type UpdateKeysPayload ¶
type UpdateKeysPayload interface{}
UpdateKeysPayload is the keys update action payload.